ConfigLoader class

Loads NebulaProjectConfig from disk.

Constructors

ConfigLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exists([String path = _defaultPath]) Future<bool>
Returns true if a config file exists at path.
load([String path = _defaultPath]) Future<NebulaProjectConfig?>
Loads config from path. Returns null if the file does not exist. Throws FormatException if the file is not valid JSON.
loadOrDefault(NebulaProjectConfig defaults, [String path = _defaultPath]) Future<NebulaProjectConfig>
Loads config from path, falling back to defaults if not found.
save(NebulaProjectConfig config, [String path = _defaultPath]) Future<void>
Writes config to path.