NebulaProjectConfig class

Project-level configuration read from nebula.config.json.

Constructors

NebulaProjectConfig({required String input, required String output, String? baseUrl, bool format = true, bool deduplicate = true, bool inferNullability = true, bool verbose = false, bool watch = false, Map<String, bool> features = const {'cache' : true, 'retry' : true, 'logging' : true, 'offline' : false}})
const
NebulaProjectConfig.fromJson(Map<String, dynamic> json)
factory

Properties

baseUrl String?
final
deduplicate bool
final
features Map<String, bool>
final
format bool
final
hashCode int
The hash code for this object.
no setterinherited
inferNullability bool
final
input String
final
output String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final
watch bool
final

Methods

feature(String name) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited