SpecWatcher class

Constructors

SpecWatcher({required String specPath, required RebuildFn onRebuild, Duration debounce = const Duration(milliseconds: 150)})

Properties

debounce Duration
final
hashCode int
The hash code for this object.
no setterinherited
onRebuild RebuildFn
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specPath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Starts watching. Runs until stop is called or the process exits.
stop() Future<void>
Stops the watcher
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited