ApiModel class

AST node for a schema object that will be emitted as a Dart class.

name — PascalCase class name. fields — ordered list of ApiFields. description — optional class-level doc comment. isAbstract — if true the generator emits an abstract class. parentName — for allOf single-parent inheritance. mixins — for allOf multi-schema composition.

Constructors

ApiModel({required String name, required List<ApiField> fields, String? description, bool isAbstract = false, String? parentName, List<String> mixins = const []})
const

Properties

description String?
final
fields List<ApiField>
final
hashCode int
The hash code for this object.
no setterinherited
isAbstract bool
final
mixins List<String>
final
name String
final
optionalFields List<ApiField>
no setter
parentName String?
final
requiredFields List<ApiField>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuralSignature String
A deterministic string that captures the structure of this model, regardless of its name. Two models with the same structuralSignature are semantically identical and can be merged by SchemaDeduplicator.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited