PluginChain class

Constructors

PluginChain(List<ApiPlugin> plugins)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
plugins List<ApiPlugin>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes all plugins.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runError(ApiRequest request, ApiError error) Future<ApiError>
Passes error through all plugins' onError hooks in reverse.
runRequest(ApiRequest request) Future<ApiRequest>
Passes request through all plugins' onRequest hooks in order.
runResponse(ApiRequest request, ApiResponse response) Future<ApiResponse>
Passes response through all plugins' onResponse hooks in reverse.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited