SyncException class

Thrown when the offline SyncEngine encounters a fatal error.

Inheritance

Constructors

SyncException(String message, {required int failedItems, Object? cause})
const

Properties

cause Object?
finalinherited
failedItems int
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited