SpecWatcher class
Constructors
- SpecWatcher({required String specPath, required RebuildFn onRebuild, Duration debounce = const Duration(milliseconds: 150)})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> - Starts watching. Runs until stop is called or the process exits.
-
stop(
) → Future< void> - Stops the watcher
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited