OpenApiParser class
Constructors
- OpenApiParser()
-
const
Properties
- formatName → String
-
A human-readable name for this format, used in CLI output.
E.g.
'OpenAPI 3.x','Swagger 2.0'.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canParse(
Map< String, dynamic> spec) → bool -
Returns
trueif this parser can handle the given decoded spec map.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
Map< String, dynamic> spec) → ParseResult -
Parses
specand returns a ParseResult containing the ApiAst and any warnings emitted during parsing.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited